#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_NEXTPOW2_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_NEXTPOW2_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/simd/nextpow2.hpp>

#endif
